@@ -71,9 +71,8 @@ struct _GstMpeg2dec {
   /* video state */
   GstVideoCodecState *input_state;
   GstVideoInfo        decoded_info;
-  GstVideoAlignment   valign;
-  GstBufferPool *     downstream_pool;
-  gboolean            need_alignment;
+  gboolean       need_cropping;
+  gboolean       has_cropping;
 
   guint8        *dummybuf[4];
 };
