@@ -213,7 +213,7 @@ gst_x264_enc_pass_get_type (void)
 
   static const GEnumValue pass_types[] = {
     {GST_X264_ENC_PASS_CBR, "Constant Bitrate Encoding", "cbr"},
-    {GST_X264_ENC_PASS_QUANT, "Constant Quantizer (debugging only)", "quant"},
+    {GST_X264_ENC_PASS_QUANT, "Constant Quantizer", "quant"},
     {GST_X264_ENC_PASS_QUAL, "Constant Quality", "qual"},
     {GST_X264_ENC_PASS_PASS1, "VBR Encoding - Pass 1", "pass1"},
     {GST_X264_ENC_PASS_PASS2, "VBR Encoding - Pass 2", "pass2"},
@@ -720,7 +720,7 @@ gst_x264_enc_class_init (GstX264EncClass * klass)
   g_object_class_install_property (gobject_class, ARG_QUANTIZER,
       g_param_spec_uint ("quantizer", "Constant Quantizer",
           "Constant quantizer or quality to apply",
-          1, 50, ARG_QUANTIZER_DEFAULT,
+          0, 50, ARG_QUANTIZER_DEFAULT,
           G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
   g_object_class_install_property (gobject_class, ARG_BITRATE,
       g_param_spec_uint ("bitrate", "Bitrate", "Bitrate in kbit/sec", 1,
@@ -880,18 +880,18 @@ gst_x264_enc_class_init (GstX264EncClass * klass)
   g_string_append_printf (x264enc_defaults, ":cabac=%d", ARG_CABAC_DEFAULT);
   g_object_class_install_property (gobject_class, ARG_QP_MIN,
       g_param_spec_uint ("qp-min", "Minimum Quantizer",
-          "Minimum quantizer", 1, 51, ARG_QP_MIN_DEFAULT,
+          "Minimum quantizer", 0, 51, ARG_QP_MIN_DEFAULT,
           G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
   g_string_append_printf (x264enc_defaults, ":qpmin=%d", ARG_QP_MIN_DEFAULT);
   g_object_class_install_property (gobject_class, ARG_QP_MAX,
       g_param_spec_uint ("qp-max", "Maximum Quantizer",
-          "Maximum quantizer", 1, 51, ARG_QP_MAX_DEFAULT,
+          "Maximum quantizer", 0, 51, ARG_QP_MAX_DEFAULT,
           G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
   g_string_append_printf (x264enc_defaults, ":qpmax=%d", ARG_QP_MAX_DEFAULT);
   g_object_class_install_property (gobject_class, ARG_QP_STEP,
       g_param_spec_uint ("qp-step", "Maximum Quantizer Difference",
           "Maximum quantizer difference between frames",
-          1, 50, ARG_QP_STEP_DEFAULT,
+          0, 50, ARG_QP_STEP_DEFAULT,
           G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
   g_string_append_printf (x264enc_defaults, ":qpstep=%d", ARG_QP_STEP_DEFAULT);
   g_object_class_install_property (gobject_class, ARG_IP_FACTOR,
@@ -1223,44 +1223,35 @@ gst_x264_enc_gst_to_x264_video_format (GstVideoFormat format, gint * nplanes)
       if (nplanes)
         *nplanes = 3;
       return X264_CSP_I420;
-      break;
     case GST_VIDEO_FORMAT_I420_10BE:
     case GST_VIDEO_FORMAT_I420_10LE:
       if (nplanes)
         *nplanes = 3;
       return X264_CSP_I420 | X264_CSP_HIGH_DEPTH;
-      break;
     case GST_VIDEO_FORMAT_Y42B:
       if (nplanes)
         *nplanes = 3;
       return X264_CSP_I422;
-      break;
     case GST_VIDEO_FORMAT_I422_10BE:
     case GST_VIDEO_FORMAT_I422_10LE:
       if (nplanes)
         *nplanes = 3;
       return X264_CSP_I422 | X264_CSP_HIGH_DEPTH;
-      break;
     case GST_VIDEO_FORMAT_Y444:
       if (nplanes)
         *nplanes = 3;
       return X264_CSP_I444;
-      break;
     case GST_VIDEO_FORMAT_Y444_10BE:
     case GST_VIDEO_FORMAT_Y444_10LE:
       if (nplanes)
         *nplanes = 3;
       return X264_CSP_I444 | X264_CSP_HIGH_DEPTH;
-      break;
     case GST_VIDEO_FORMAT_NV12:
       if (nplanes)
         *nplanes = 2;
       return X264_CSP_NV12;
-      break;
     default:
-      g_assert_not_reached ();
-      return GST_VIDEO_FORMAT_UNKNOWN;
-      break;
+      g_return_val_if_reached (GST_VIDEO_FORMAT_UNKNOWN);
   }
 }
 
@@ -1552,6 +1543,10 @@ gst_x264_enc_set_profile_and_level (GstX264Enc * encoder, GstCaps * caps)
   profile = gst_structure_get_string (s, "profile");
 
   allowed_caps = gst_pad_get_allowed_caps (GST_VIDEO_ENCODER_SRC_PAD (encoder));
+
+  if (allowed_caps == NULL)
+    goto no_peer;
+
   if (!gst_caps_can_intersect (allowed_caps, caps)) {
     allowed_caps = gst_caps_make_writable (allowed_caps);
     allowed_caps = gst_caps_truncate (allowed_caps);
@@ -1581,6 +1576,8 @@ gst_x264_enc_set_profile_and_level (GstX264Enc * encoder, GstCaps * caps)
   }
   gst_caps_unref (allowed_caps);
 
+no_peer:
+
   return TRUE;
 }
 
@@ -1807,6 +1804,7 @@ gst_x264_enc_set_format (GstVideoEncoder * video_enc,
 
     if (gst_caps_is_empty (allowed_caps)) {
       gst_caps_unref (allowed_caps);
+      gst_caps_unref (template_caps);
       return FALSE;
     }
 
@@ -1941,7 +1939,7 @@ gst_x264_enc_handle_frame (GstVideoEncoder * video_enc,
   x264_picture_t pic_in;
   gint i_nal, i;
   FrameData *fdata;
-  gint nplanes;
+  gint nplanes = 0;
 
   if (G_UNLIKELY (encoder->x264enc == NULL))
     goto not_inited;
